@@ -76,9 +76,9 @@ from josepy.util import (
     ImmutableMap,
 )
 
-if sys.version_info[:2] == (3, 6):
+if sys.version_info[:2] == (3, 7):
     warnings.warn(
-            "Python 3.6 support will be dropped in the next release of "
-            "josepy. Please upgrade your Python version.",
-            DeprecationWarning,
+        "Python 3.7 support will be dropped in the next scheduled release of "
+        "josepy. Please upgrade your Python version.",
+        DeprecationWarning,
     )
